==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/igc-geographic-tile-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcImageTilesReadyEventArgs } from "./igc-image-tiles-ready-event-args";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicTileSeries } from "./GeographicTileSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class used for displaying a tile set, and using shapes to define the areas that should be rendered.
*/
export let IgcGeographicTileSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicTileSeriesComponent extends IgcGeographicShapeSeriesBaseComponent {
        createImplementation() {
            return new GeographicTileSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._imageTilesReady = null;
            this._imageTilesReady_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicTileSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent = names;
            }
            return IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent;
        }
        static register() {
            if (!IgcGeographicTileSeriesComponent._isElementRegistered) {
                IgcGeographicTileSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicTileSeriesComponent.htmlTagName, IgcGeographicTileSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a tile imagery.
        */
        get isTile() {
            return this.i.fh;
        }
        /**
         * The MapImagery which is used to provide the tiles for display.
        */
        get tileImagery() {
            const r = this.i.vd;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        }
        set tileImagery(v) {
            v == null ? this.i.vd = null : this.i.vd = v.i;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.tileImagery && this.tileImagery.name && this.tileImagery.name == name) {
                return this.tileImagery;
            }
            return null;
        }
        /**
         * Removes all cached tile Imagery from the
        
        */
        clearTileCache() {
            this.i.vh();
        }
        /**
         * This event is fired whenever the image tiles transition from a loading state (e.g. some are fading in) to a loaded state.
        */
        get imageTilesReady() {
            return this._imageTilesReady;
        }
        set imageTilesReady(ev) {
            if (this._imageTilesReady_wrapped !== null) {
                this.i.imageTilesReady = delegateRemove(this.i.imageTilesReady, this._imageTilesReady_wrapped);
                this._imageTilesReady_wrapped = null;
                this._imageTilesReady = null;
            }
            this._imageTilesReady = ev;
            this._imageTilesReady_wrapped = (o, e) => {
                let outerArgs = new IgcImageTilesReadyEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeImageTilesReady) {
                    this.beforeImageTilesReady(this, outerArgs);
                }
                if (this._imageTilesReady) {
                    this._imageTilesReady(this, outerArgs);
                }
            };
            this.i.imageTilesReady = delegateCombine(this.i.imageTilesReady, this._imageTilesReady_wrapped);
            ;
        }
    }
    IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent = null;
    IgcGeographicTileSeriesComponent.htmlTagName = "igc-geographic-tile-series";
    IgcGeographicTileSeriesComponent._isElementRegistered = false;
    return IgcGeographicTileSeriesComponent;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/igc-geographic-tile-series-component.js <==
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcImageTilesReadyEventArgs } from "./igc-image-tiles-ready-event-args";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicTileSeries } from "./GeographicTileSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class used for displaying a tile set, and using shapes to define the areas that should be rendered.
*/
export let IgcGeographicTileSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicTileSeriesComponent extends IgcGeographicShapeSeriesBaseComponent {
        createImplementation() {
            return new GeographicTileSeries();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._imageTilesReady = null;
            this._imageTilesReady_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicTileSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent = names;
            }
            return IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent;
        }
        static register() {
            if (!IgcGeographicTileSeriesComponent._isElementRegistered) {
                IgcGeographicTileSeriesComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcGeographicTileSeriesComponent.htmlTagName, IgcGeographicTileSeriesComponent);
            }
        }
        /**
         * Gets whether the current series shows a tile imagery.
        */
        get isTile() {
            return this.i.f3;
        }
        /**
         * The MapImagery which is used to provide the tiles for display.
        */
        get tileImagery() {
            const r = this.i.yj;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        }
        set tileImagery(v) {
            v == null ? this.i.yj = null : this.i.yj = v.i;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.tileImagery && this.tileImagery.name && this.tileImagery.name == name) {
                return this.tileImagery;
            }
            return null;
        }
        /**
         * Removes all cached tile Imagery from the
        
        */
        clearTileCache() {
            this.i.yn();
        }
        /**
         * This event is fired whenever the image tiles transition from a loading state (e.g. some are fading in) to a loaded state.
        */
        get imageTilesReady() {
            return this._imageTilesReady;
        }
        set imageTilesReady(ev) {
            if (this._imageTilesReady_wrapped !== null) {
                this.i.imageTilesReady = delegateRemove(this.i.imageTilesReady, this._imageTilesReady_wrapped);
                this._imageTilesReady_wrapped = null;
                this._imageTilesReady = null;
            }
            this._imageTilesReady = ev;
            this._imageTilesReady_wrapped = (o, e) => {
                let outerArgs = new IgcImageTilesReadyEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeImageTilesReady) {
                    this.beforeImageTilesReady(this, outerArgs);
                }
                if (this._imageTilesReady) {
                    this._imageTilesReady(this, outerArgs);
                }
            };
            this.i.imageTilesReady = delegateCombine(this.i.imageTilesReady, this._imageTilesReady_wrapped);
            ;
        }
    }
    IgcGeographicTileSeriesComponent._observedAttributesIgcGeographicTileSeriesComponent = null;
    IgcGeographicTileSeriesComponent.htmlTagName = "igc-geographic-tile-series";
    IgcGeographicTileSeriesComponent._isElementRegistered = false;
    return IgcGeographicTileSeriesComponent;
})();
